@@ -121,6 +121,7 @@ class BaseSnatch:
     def _format_response(self, data: Dict[Any, Any]) -> BaseData:
         data_obj = self.serializer_class().load(data)
         data_obj.current_environment = self.settings["current_environment"]
+        data_obj.datasource_base_url = self.base_url
         return data_obj
 
     def _format_error_response(self, error):
@@ -128,25 +129,31 @@ class BaseSnatch:
             error.response.status_code if hasattr(error, "response") else "N/D"
         )
         integration_status = "NOT_FOUND" if status_code == 404 else "CONN_ERROR"
+        if integration_status == "CONN_ERROR":
+            payload = {}
+        else:
+            payload = error.response.json() if hasattr(error, "response") else {}
         data_obj = self.serializer_class().load(
             {
                 "status_reason": f"Status Code: {status_code} "
                 f"when accessing {error.request.url}",
-                "integration_status": integration_status,
-                "payload": error.response.json() if hasattr(error, "response") else {},
+                "status": integration_status,
+                "payload": payload,
             }
         )
         data_obj.current_environment = self.settings["current_environment"]
+        data_obj.datasource_base_url = self.base_url
         return data_obj
 
     def _format_timeout_response(self, url):
         data_obj = self.serializer_class().load(
             {
                 "status_reason": f"Timeout when accessing: {url}",
-                "integration_status": "TIMEOUT",
+                "status": "TIMEOUT",
             }
         )
         data_obj.current_environment = self.settings["current_environment"]
+        data_obj.datasource_base_url = self.base_url
         return data_obj
 
     def _request_and_create_data(
